from os import getcwd
from pathlib import Path

from je_editor.pyside_ui.main_ui.save_settings.setting_utils import write_setting
from je_editor.utils.json.json_file import read_json
from je_editor.utils.logging.loggin_instance import jeditor_logger

user_setting_dict = {
    "ui_font": "Lato",
    "ui_font_size": 12,
    "language": "English",
    "ui_style": "dark_amber.xml",
    "font": "Lato",
    "font_size": 12,
    "encoding": "utf-8",
    "last_file": None,
    "python_compiler": None,
    "max_line_of_output": 200000,
}


def write_user_setting() -> None:
    jeditor_logger.info("user_setting_file.py write_user_setting")
    write_setting(user_setting_dict, "user_setting.json")


def read_user_setting() -> None:
    jeditor_logger.info("user_setting_file.py read_user_setting")
    user_setting_file = Path(getcwd() + "/.jeditor/user_setting.json")
    if user_setting_file.exists() and user_setting_file.is_file():
        user_setting_dict.update(read_json(str(user_setting_file)))



from je_editor.pyside_ui.browser.browser_widget import BrowserWidget
from je_editor.pyside_ui.code.code_process.code_exec import ExecManager
from je_editor.pyside_ui.code.shell_process.shell_exec import ShellManager
from je_editor.pyside_ui.code.syntax.python_syntax import PythonHighlighter
from je_editor.pyside_ui.code.syntax.syntax_setting import syntax_extend_setting_dict, syntax_rule_setting_dict
from je_editor.pyside_ui.main_ui.editor.editor_widget import EditorWidget
from je_editor.pyside_ui.main_ui.editor.editor_widget_dock import FullEditorWidget
from je_editor.pyside_ui.main_ui.main_editor import EDITOR_EXTEND_TAB
from je_editor.pyside_ui.main_ui.main_editor import EditorMain
from je_editor.pyside_ui.main_ui.save_settings.user_color_setting_file import user_setting_color_dict
from je_editor.pyside_ui.main_ui.save_settings.user_setting_file import user_setting_dict
from je_editor.start_editor import start_editor
from je_editor.utils.exception.exceptions import JEditorCantFindLanguageException
from je_editor.utils.exception.exceptions import JEditorContentFileException
from je_editor.utils.exception.exceptions import JEditorException
from je_editor.utils.exception.exceptions import JEditorExecException
from je_editor.utils.exception.exceptions import JEditorJsonException
from je_editor.utils.exception.exceptions import JEditorOpenFileException
from je_editor.utils.exception.exceptions import JEditorRunOnShellException
from je_editor.utils.exception.exceptions import JEditorSaveFileException
from je_editor.utils.multi_language.english import english_word_dict
from je_editor.utils.multi_language.multi_language_wrapper import language_wrapper
from je_editor.utils.multi_language.traditional_chinese import traditional_chinese_word_dict

__all__ = [
    "start_editor", "EditorMain", "EDITOR_EXTEND_TAB",
    "JEditorException", "JEditorExecException", "FullEditorWidget",
    "JEditorRunOnShellException", "JEditorSaveFileException", "syntax_rule_setting_dict",
    "JEditorOpenFileException", "JEditorContentFileException", "syntax_extend_setting_dict",
    "JEditorCantFindLanguageException", "JEditorJsonException", "PythonHighlighter",
    "user_setting_dict", "user_setting_color_dict", "EditorWidget", "BrowserWidget",
    "ExecManager", "ShellManager", "traditional_chinese_word_dict", "english_word_dict",
    "language_wrapper"
]
